@@ -10,7 +10,7 @@
 
 
 /* -------------- CH_CHAR -------------- */
-char * ch_char(char * data, char * backdata)
+int ch_char(char * data, char * backdata)
 {
 int count;
 int ret = 0;
