@@ -124,19 +124,19 @@ echo " start = $STARTTIME \n";
 echo " stop = $STOPSETTIME \n";
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "NG not connection!<br>";
    exit;
    }
 
 
-$result = pg_query($conn, "select * from connection where cname='$CNAME';");
+$result = db_query($conn, "select * from connection where cname='$CNAME';");
 if(!$result){
    print("bud query set(select)\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    print("OK ƻ륯饤Ȥ¸ߤޤ\n");
    }
@@ -144,15 +144,15 @@ else{
    print("NG ƻ륯饤Ȥ¸ߤޤ\n");
    exit;
    }
-pg_free_result($result);
+db_free_result($result);
 
 
-$result = pg_query($conn, "select * from userblock where bname='$BNAME';");
+$result = db_query($conn, "select * from userblock where bname='$BNAME';");
 if(!$result){
    print("bud update query set\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 
 if($num > 0){
    print("OK ƻ֥åϤǤ¸ߤޤ\n");
@@ -160,18 +160,18 @@ if($num > 0){
    if("ON" == $EDIT){
       print("OK Խ⡼ɤʤΤǾ񤭤ޤ\n");
 
-      $result=pg_query($conn, "select * from userblock where bname='$BNAME'");
+      $result=db_query($conn, "select * from userblock where bname='$BNAME'");
       if(!$result){
          print("bud query set\n");
          exit;
          }
-      $num2 = pg_num_rows($result);
+      $num2 = db_num_rows($result);
       if($num2 > 0){
-         $CNAME_OLD = enco_rtrim(pg_fetch_Result($result, $s, cname));
-         $BNAME_OLD = enco_rtrim(pg_fetch_Result($result, $s, bname));
+         $CNAME_OLD = enco_rtrim(db_fetch_Result($result, $s, cname));
+         $BNAME_OLD = enco_rtrim(db_fetch_Result($result, $s, bname));
          }
 
-      $result = pg_query($conn, "update userblock set
+      $result = db_query($conn, "update userblock set
         youname='$YOUNAME',
         bname='$BNAME', 
         cname='$CNAME',
@@ -188,7 +188,7 @@ if($num > 0){
         where bname='$BNAME'");
 
       print("OK ƻܤ֤Ƥޤ\n");
-      $result =pg_query($conn,
+      $result =db_query($conn,
         "update monitor set free4='$BNAME',
                             cname='$CNAME'
                       where free4='$BNAME_OLD' and cname='$CNAME_OLD'");
@@ -213,7 +213,7 @@ if($num > 0){
 if($num <= 0){
    if("ON" != $EDIT){
       print("OK Խ⡼ɤ̵Τǡƻ֥åޤ\n");
-      $result = pg_query($conn, "insert into userblock values (
+      $result = db_query($conn, "insert into userblock values (
        '$YOUNAME',
        '$BNAME', 
        '$CNAME',
@@ -237,8 +237,8 @@ if($num <= 0){
 
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 print("</font>");
 
