@@ -75,7 +75,7 @@ if(0 == strlen($CIP)){
    }
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -84,26 +84,26 @@ if(!$conn){
 
 if(0 < strlen($GEN)){
 
-   $result = pg_query($conn, "select * from connection where cname='$C_NAME';");
+   $result = db_query($conn, "select * from connection where cname='$C_NAME';");
    if(!$result){
       print("bud query set(select)\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num > 0){
       print("connection.sql˥ǡ¸ߤޤ³Ԥޤ\n");
       }
 
 
-   $result = pg_query($conn, "select * from config where c_name='$C_NAME';");
+   $result = db_query($conn, "select * from config where c_name='$C_NAME';");
    if(!$result){
       print("bud update query set\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num > 0){
       print("config.sql˥ǡ¸ߤޤ񤭤ޤ\n");
-      $result = pg_query($conn, "update config set
+      $result = db_query($conn, "update config set
        c_name='$C_NAME',
        c_info='$C_INFO',
        sock_ipaddr='$SOCK_IPADDR',
@@ -129,7 +129,25 @@ if(0 < strlen($GEN)){
       }
    else{
       print("config.sql˥ǡʤΤǡ˺ޤ\n");
-      $result = pg_query($conn, "insert into config values (
+      $result = db_query($conn, "insert into config
+        (
+        c_name,
+        c_info,
+        sock_ipaddr,
+        sock_port,
+        sock2_ipaddr,
+        sock2_port,
+        bat_file,
+        bat2_file,
+        command_path,
+        bat_int,
+        bat2_int,
+        life_int,
+        life_los,
+        mail_cc,
+        update_com,
+        up_time
+        ) values (
        '$C_NAME',
        '$C_INFO',
        '$SOCK_IPADDR',
@@ -155,14 +173,14 @@ if(0 < strlen($GEN)){
       }
 
 
-   $result = pg_query($conn, "select * from connection where cname='$C_NAME';");
+   $result = db_query($conn, "select * from connection where cname='$C_NAME';");
    if(!$result){
       print("bud query set(select)\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num > 0){
-      $result = pg_query($conn, "update connection set
+      $result = db_query($conn, "update connection set
        cname='$C_NAME',
        cip='$CIP'
        where cname='$C_NAME'");
@@ -175,7 +193,21 @@ if(0 < strlen($GEN)){
       }
 
    else{
-      $result = pg_query($conn, "insert into connection values (
+      $result = db_query($conn, "insert into connection
+       (
+       uct,
+       ye,
+       mo,
+       da,
+       ha,
+       mi,
+       se,
+       cname,
+       cip,
+       server,
+       mode,
+       stat
+       ) values (
        0,
        0,
        0,
@@ -202,12 +234,12 @@ if(0 < strlen($GEN)){
 
 
 $start_file = "/usr/local/zither/conf/$C_NAME.conf";
-$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
+$result = db_query($conn, "select * from config where c_name='$C_NAME';");
 if(!$result){
    print("bud query config\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    if(($fp = fopen($start_file, "w+"))==NULL){
       print("file not open $start_file\n");
@@ -215,37 +247,37 @@ if($num > 0){
       }
    $s = 0;
    while($s < $num){
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, c_name));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, c_name));
       if(0 != strlen($DATA)){ fwrite($fp, "C_NAME:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, c_info));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, c_info));
       if(0 != strlen($DATA)){ fwrite($fp, "C_INFO:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock_ipaddr));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK_IPADDR:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock2_ipaddr));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_IPADDR:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock_port));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock_port));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK_PORT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock2_port));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock2_port));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_PORT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat_file));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat_file));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT_FILE:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat2_file));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat2_file));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT2_FILE:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, command_path));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, command_path));
       if(0 != strlen($DATA)){ fwrite($fp, "COMMAND_PATH:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat_int));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat_int));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT_INT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat2_int));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat2_int));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT2_INT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, life_int));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, life_int));
       if(0 != strlen($DATA)){ fwrite($fp, "LIFE_INT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, life_los));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, life_los));
       if(0 != strlen($DATA)){ fwrite($fp, "LIFE_LOS:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, mail_cc));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, mail_cc));
       if(0 != strlen($DATA)){ fwrite($fp, "MAIL_CC:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, update_com));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, update_com));
       if(0 != strlen($DATA)){ fwrite($fp, "UPDATE_COM:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, up_time));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, up_time));
 
       $s++;
       }
@@ -264,49 +296,6 @@ else{
 echo "ԽǤϤʤΤǡƻܤξ񤭤ϹԤޤ\n";
 
 
-// $result = pg_query($conn, "select * from monitor where cname='$C_NAME';");
-// if(!$result){
-//   print("bud query set(select)\n");
-//   exit;
-//   }
-//$num = pg_num_rows($result);
-//if($num < 1){
-//   print("ƻܤ¸ߤʤΤǡƤȤɲäƤޤ\n");
-//   if(0 == strcmp($COM_MONITOR, "ON")){   
-
-//      $result = pg_query($conn, "insert into monitor values (    'OFF', '$C_NAME', 'COMAND', 0, 'NOT', 'dfc.sh none 90', '$CIP', 'NOT', 5, '$C_NAME($CIP)', 4, 'NOT', 'NOT', 'NOT', 'NOT') ");
-//      if(!$result){
-//         print("bud query set\n");
-//         exit;
-//         }
-
-//      $result = pg_query($conn, "insert into monitor values (    'OFF', '$C_NAME', 'COMAND', 0, 'NOT', 'inode.sh none 20', '$CIP', 'NOT', 5, '$C_NAME($CIP)', 4, 'NOT', 'NOT', 'NOT', 'NOT') ");
-//      if(!$result){
-//         print("bud query set\n");
-//         exit;
-//         }
-
-//      $result = pg_query($conn, "insert into monitor values (    'OFF', '$C_NAME', 'COMAND', 0, 'NOT', 'uptime.sh 20', '$CIP', 'NOT', 5, '$C_NAME($CIP)', 4, 'NOT', 'NOT', 'NOT', 'NOT') ");
-//      if(!$result){
-//         print("bud query set\n");
-//         exit;
-//         }
-
-//      $result = pg_query($conn, "insert into monitor values (    'OFF', '$C_NAME', 'COMAND', 0, 'NOT', 'freemem.sh 1000', '$CIP', 'NOT', 5, '$C_NAME($CIP)', 4, 'NOT', 'NOT', 'NOT', 'NOT') ");
-//      if(!$result){
-//         print("bud query set\n");
-//         exit;
-//         }        
-//      }
-
-
-//   echo "OK Inser data\n";
-//   echo "$C_NAME\n";
-//   echo "$CIP\n";
-//   }
-//
-
-
 
 echo "STATե񤭤ޤ\n";
 
@@ -322,12 +311,12 @@ else{
    fclose($fp);
    }
 
-$result = pg_query($conn, "select * from connection where cname='$C_NAME'");
+$result = db_query($conn, "select * from connection where cname='$C_NAME'");
 if(!$result){
    print("bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    if(($fp = fopen($conf_file, "w+"))==NULL){
       print("stat file not open\n");
@@ -342,7 +331,7 @@ if($num <= 0){
 else{
    $s = 0;
    while($s < $num){
-      $MODE = enco_rtrim(pg_fetch_Result($result, $s, mode));
+      $MODE = enco_rtrim(db_fetch_Result($result, $s, mode));
       if(0 != strcmp($MODE, $outdata)){
          echo "OUT MODE -->$MODE\n";
          if(($fp = fopen($conf_file, "w+"))==NULL){
@@ -360,88 +349,24 @@ else{
 
 
 
-
-// $conf_file = "/usr/local/zither/conf/$C_NAME.command";
-// if(($fp = fopen($conf_file, "w+"))==NULL){
-//    print("file not open\n");
-//   exit;
-//   }
-// fwrite($fp, "##\n");
-// fwrite($fp, "##\n");
-// fclose($fp);
-// echo "file update ok\n";
-// echo " \n";
-
 echo "ԽǤϤʤΤǡޥɥեϾ񤭤ޤ\n";
 
 
-// print("ƻꥹȥեȿǤƤޤ\n");
-// --- list file upload --- //
-// list_file_upload($C_NAME, $GEN);
-
 
 echo "ԽǤϤʤΤǡLISTեϾ񤭤ޤ \n";
 
-// $conf_file = "/usr/local/zither/conf/$C_NAME.list";
-// $result = pg_query($conn, "select * from monitor where cname='$C_NAME'");
-// if(!$result){
-//  print("bud query\n");
-//   exit;
-//  }
-// $num = pg_num_rows($result);
-// if($num <= 0){
-//   print("no data\n");
-//   exit;
-//   }
-// if(($fp = fopen($conf_file, "w+"))==NULL){
-//   print("file not open\n");
-//   exit;
-//   }
-//$s = 0;
-//while($s < $num){
-//   $COME = enco_rtrim(pg_fetch_Result($result, $s, come));
-//   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-//   $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
-//   $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
-//   $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
-//   $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
-//   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-//   $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
-//   $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
-//   $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
-//   $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
-//   $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
-//   $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
-//   $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
-//   $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
-//   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
-
-
-//   if(0 == strcmp($COME, "OFF")){
-//      fwrite($fp, "# ");
-//      }
-//   else{
-//      }
-//   fwrite($fp, "$MONITOR,$SIGN,$PROTO,$COM,$CIP,$PORT,$WTIME,$PINFO,$PRINO,$FREE1,$FREE2,$FREE3,$FREE4,\n");
-//   $s++;
-//   }
-
-
-//fclose($fp);
-//echo "all file update ok\n";
-//echo " \n";
 
 
 echo "ǧڥե񤭤ޤ\n";
 
 
 $conf_file = "/usr/local/zither/conf/neg.conf";
-$result = pg_query($conn, "select * from connection");
+$result = db_query($conn, "select * from connection");
 if(!$result){
    print("bud query conection\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data conection\n");
    exit;
@@ -452,8 +377,8 @@ if(($fp = fopen($conf_file, "w+"))==NULL){
    }
 $s = 0;
 while($s < $num){
-   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
    fwrite($fp, "$CNAME:$CIP\n");
    print("$CNAME:$CIP\n");
    $s++;
@@ -466,19 +391,19 @@ echo " \n";
 
 if(0 < strlen($GEN)){
    $s = 0;
-   $result = pg_query($conn, "select distinct(server) from connection;");
+   $result = db_query($conn, "select distinct(server) from connection;");
    if(!$result){
       print("bud query\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num <= 0){
       print("no data\n");
       exit;
       }
    else{
       while($s < $num){
-         $SERVER = enco_rtrim(pg_fetch_Result($result, $s, server));
+         $SERVER = enco_rtrim(db_fetch_Result($result, $s, server));
          print("$SERVER $my_web_ip ");
          if(0 != strcmp($SERVER, $my_web_ip)){
 
@@ -517,8 +442,8 @@ if(0 < strlen($GEN)){
    }
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 print("</font>");
 
