@@ -74,33 +74,33 @@ if(0 == strlen($CIP)){
    }
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
 echo "NG DB³ޤ<br>";
    exit;
    }
 
 
-$result = pg_query($conn, "select * from connection where cname='$C_NAME';");
+$result = db_query($conn, "select * from connection where cname='$C_NAME';");
 if(!$result){
    print("NG 䤤碌Ǥ\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    print("NG Ǥ˥ǡ¸ߤޤ\n");
    exit;
    }
 
 
-$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
+$result = db_query($conn, "select * from config where c_name='$C_NAME';");
 if(!$result){
    print("NG 䤤碌Ǥ 1\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
-   $result = pg_query($conn, "update config set
+   $result = db_query($conn, "update config set
     c_name='$C_NAME',
     c_info='$C_INFO',
     sock_ipaddr='$SOCK_IPADDR',
@@ -125,7 +125,25 @@ if($num > 0){
       }
    }
 else{
-   $result = pg_query($conn, "insert into config values (
+   $result = db_query($conn, "insert into config
+    (
+    c_name,
+    c_info,
+    sock_ipaddr,
+    sock_port,
+    sock2_ipaddr,
+    sock2_port,
+    bat_file,
+    bat2_file,
+    command_path,
+    bat_int,
+    bat2_int,
+    life_int,
+    life_los,
+    mail_cc,
+    update_com,
+    up_time
+     ) values (
     '$C_NAME',
     '$C_INFO',
     '$SOCK_IPADDR',
@@ -151,14 +169,14 @@ else{
    }
 
 
-$result = pg_query($conn, "select * from connection where cname='$C_NAME';");
+$result = db_query($conn, "select * from connection where cname='$C_NAME';");
 if(!$result){
    print("NG 䤤碌Ǥ 2\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
-   $result = pg_query($conn, "update connection set
+   $result = db_query($conn, "update connection set
     cname='$C_NAME',
     cip='$CIP'
     where cname='$C_NAME'");
@@ -171,7 +189,21 @@ if($num > 0){
    }
 
 else{
-   $result = pg_query($conn, "insert into connection values (
+   $result = db_query($conn, "insert into connection
+    (
+    uct,
+    ye,
+    mo,
+    da,
+    ha,
+    mi,
+    se,
+    cname,
+    cip,
+    server,
+    mode,
+    stat
+    ) values (
     0,
     0,
     0,
@@ -195,12 +227,12 @@ else{
 
 
 $start_file = "/usr/local/zither/conf/$C_NAME.conf";
-$result = pg_query($conn, "select * from config where c_name='$C_NAME';");
+$result = db_query($conn, "select * from config where c_name='$C_NAME';");
 if(!$result){
    print("NG ְä꡼Ǥ4\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    if(($fp = fopen($start_file, "w+"))==NULL){
       print("NG file not open $start_file\n");
@@ -208,37 +240,37 @@ if($num > 0){
       }
    $s = 0;
    while($s < $num){
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, c_name));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, c_name));
       if(0 != strlen($DATA)){ fwrite($fp, "C_NAME:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, c_info));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, c_info));
       if(0 != strlen($DATA)){ fwrite($fp, "C_INFO:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock_ipaddr));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock_ipaddr));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK_IPADDR:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock2_ipaddr));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock2_ipaddr));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_IPADDR:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock_port));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock_port));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK_PORT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, sock2_port));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, sock2_port));
       if(0 != strlen($DATA)){ fwrite($fp, "SOCK2_PORT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat_file));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat_file));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT_FILE:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat2_file));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat2_file));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT2_FILE:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, command_path));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, command_path));
       if(0 != strlen($DATA)){ fwrite($fp, "COMMAND_PATH:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat_int));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat_int));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT_INT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, bat2_int));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, bat2_int));
       if(0 != strlen($DATA)){ fwrite($fp, "BAT2_INT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, life_int));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, life_int));
       if(0 != strlen($DATA)){ fwrite($fp, "LIFE_INT:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, life_los));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, life_los));
       if(0 != strlen($DATA)){ fwrite($fp, "LIFE_LOS:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, mail_cc));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, mail_cc));
       if(0 != strlen($DATA)){ fwrite($fp, "MAIL_CC:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, update_com));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, update_com));
       if(0 != strlen($DATA)){ fwrite($fp, "UPDATE_COM:$DATA\n"); }
-      $DATA = enco_rtrim(pg_fetch_Result($result, $s, up_time));
+      $DATA = enco_rtrim(db_fetch_Result($result, $s, up_time));
 
       $s++;
       }
@@ -256,42 +288,185 @@ else{
 
 
 
-$result = pg_query($conn, "select * from monitor where cname='$C_NAME';");
+$result = db_query($conn, "select * from monitor where cname='$C_NAME';");
 if(!$result){
    print("bud query set(select)\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num < 1){
 
    if(0 == strcmp($COM_MONITOR, "ON")){   
 
-      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'dfc.sh none 90', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
+      $result = db_query($conn, "insert into monitor
+         (
+         come,
+         cname,
+         monitor,
+         sign,
+         proto,
+         com,
+         cip,
+         port,
+         wtime,
+         pinfo,
+         prino,
+         free1,
+         free2,
+         free3,
+         free4
+         ) values (
+         'ON',
+         '$C_NAME',
+         'COMAND',
+         0,
+         'NOT',
+         'dfc.sh none 90',
+         '$CIP',
+         'NOT',
+         8,
+         '$C_NAME($CIP)',
+         2,
+         'NOT',
+         'NOT',
+         'NOT',
+         '$C_BLOCK_NAME') ");
       if(!$result){
          print("bud query set\n");
          exit;
          }
 
-      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'inode.sh none 40', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
+      $result = db_query($conn, "insert into monitor
+         (
+         come,
+         cname,
+         monitor,
+         sign,
+         proto,
+         com,
+         cip,
+         port,
+         wtime,
+         pinfo,
+         prino,
+         free1,
+         free2,
+         free3,
+         free4
+         ) values (
+         'ON',
+         '$C_NAME',
+         'COMAND',
+         0,
+         'NOT',
+         'inode.sh none 40',
+         '$CIP',
+         'NOT',
+         8,
+         '$C_NAME($CIP)',
+         2,
+         'NOT',
+         'NOT',
+         'NOT',
+         '$C_BLOCK_NAME') ");
       if(!$result){
          print("bud query set\n");
          exit;
          }
 
-      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'uptime.sh 40', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
+      $result = db_query($conn, "insert into monitor
+         (
+         come,
+         cname,
+         monitor,
+         sign,
+         proto,
+         com,
+         cip,
+         port,
+         wtime,
+         pinfo,
+         prino,
+         free1,
+         free2,
+         free3,
+         free4
+         ) values (
+         'ON',
+         '$C_NAME',
+         'COMAND',
+         0,
+         'NOT',
+         'uptime.sh 40',
+         '$CIP',
+         'NOT',
+         8,
+         '$C_NAME($CIP)',
+         2,
+         'NOT',
+         'NOT',
+         'NOT',
+         '$C_BLOCK_NAME') ");
       if(!$result){
          print("bud query set\n");
          exit;
          }
 
-      $result = pg_query($conn, "insert into monitor values ('ON', '$C_NAME', 'COMAND', 0, 'NOT', 'freemem.sh 1000', '$CIP', 'NOT', 8, '$C_NAME($CIP)', 2, 'NOT', 'NOT', 'NOT', '$C_BLOCK_NAME') ");
+      $result = db_query($conn, "insert into monitor
+         (
+         come,
+         cname,
+         monitor,
+         sign,
+         proto,
+         com,
+         cip,
+         port,
+         wtime,
+         pinfo,
+         prino,
+         free1,
+         free2,
+         free3,
+         free4
+         ) values (
+         'ON',
+         '$C_NAME',
+         'COMAND',
+         0,
+         'NOT',
+         'freemem.sh 1000',
+         '$CIP',
+         'NOT',
+          8,
+          '$C_NAME($CIP)',
+          2,
+          'NOT',
+          'NOT',
+          'NOT',
+          '$C_BLOCK_NAME') ");
       if(!$result){
          print("bud query set\n");
          exit;
          }        
 
       print("OK ƻ֥åޤ\n");
-      $result = pg_query($conn, "insert into userblock values (
+      $result = db_query($conn, "insert into userblock
+        (
+        youname,
+        bname,
+        cname,
+        mailsend,
+        stat,
+        plustime,
+        starttime,
+        stopsettime,
+        mailto,
+        mailcc,
+        free1,
+        free2,
+        free3
+        ) values (
         'test',
         '$C_BLOCK_NAME',
         '$C_NAME',
@@ -312,7 +487,7 @@ if($num < 1){
          }
       }
 
-   pg_free_result($result);
+   db_free_result($result);
 
    echo "OK Inser data\n";
    echo "$C_NAME\n";
@@ -329,12 +504,12 @@ if(($fp = fopen($conf_file, "w+"))==NULL){
    print("stat file not open\n");
    exit;
    }
-$result = pg_query($conn, "select * from connection where cname='$C_NAME'");
+$result = db_query($conn, "select * from connection where cname='$C_NAME'");
 if(!$result){
    print("bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data\n");
    fwrite($fp, "START");
@@ -344,7 +519,7 @@ if($num <= 0){
 else{
    $s = 0;
    while($s < $num){
-      $MODE = enco_rtrim(pg_fetch_Result($result, $s, mode));
+      $MODE = enco_rtrim(db_fetch_Result($result, $s, mode));
       fwrite($fp, $MODE);
       echo "stat file update ok\n";
       echo " \n";
@@ -389,11 +564,11 @@ echo " \n";
 
 
 $conf_file = "/usr/local/zither/conf/neg.conf";
-$result = pg_query($conn, "select * from connection");
+$result = db_query($conn, "select * from connection");
 if(!$result){
    print("bud query conection\n");
    exit;
-   }$num = pg_num_rows($result);
+   }$num = db_num_rows($result);
 if($num <= 0){
    print("no data conection\n");
    exit;
@@ -403,8 +578,8 @@ if(($fp = fopen($conf_file, "w+"))==NULL){
    exit;   }  
 $s = 0;
 while($s < $num){
-   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
    fwrite($fp, "$CNAME:$CIP\n");
    print("$CNAME:$CIP\n");
    $s++;
@@ -421,8 +596,8 @@ list_file_upload($C_NAME, $GEN);
 
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 print("</font>");
 
