@@ -36,19 +36,19 @@ print(date("Y m d g i s A"));
 print("\n");
 echo "Priority 1 = <font color=red>Red,</font> 2 = <font color=magenta>Magenta,</font> 3 = <font color=green>Green,</font>";
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
    }
 
-$result = pg_query($conn, "select * from errlog where uno='$gno'");
+$result = db_query($conn, "select * from errlog where uno='$gno'");
 if(!$result){
    print("bud query\n");
    exit;
    }
 
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data\n");
    exit;
@@ -59,30 +59,30 @@ print("\n\n");
 echo "<TABLE border=0  WIDTH=70% height=2% BGCOLOR=$my_bocolor>";
 
 while($s < $num){
-   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-   $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
-   $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
-   $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
-   $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
-   $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
-   $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
-   $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
-   $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
-   $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
-   $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
-   $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
-   $CINFO = enco_rtrim(pg_fetch_Result($result, $s, cinfo));
-   $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
-   $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
-   $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
-   $ERRDATA = enco_rtrim(pg_fetch_Result($result, $s, errdata));
-   $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
-   $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
-   $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
-   $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
-   $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
-   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
+   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
+   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+   $MONITOR = enco_rtrim(db_fetch_Result($result, $s, monitor));
+   $UCT = enco_rtrim(db_fetch_Result($result, $s, uct));
+   $YE = enco_rtrim(db_fetch_Result($result, $s, ye));
+   $MO = enco_rtrim(db_fetch_Result($result, $s, mo));
+   $DA = enco_rtrim(db_fetch_Result($result, $s, da));
+   $HA = enco_rtrim(db_fetch_Result($result, $s, ha));
+   $MI = enco_rtrim(db_fetch_Result($result, $s, mi));
+   $SE = enco_rtrim(db_fetch_Result($result, $s, se));
+   $SIGN = enco_rtrim(db_fetch_Result($result, $s, sign));
+   $PROTO = enco_rtrim(db_fetch_Result($result, $s, proto));
+   $COM = enco_rtrim(db_fetch_Result($result, $s, com));
+   $CINFO = enco_rtrim(db_fetch_Result($result, $s, cinfo));
+   $PORT = enco_rtrim(db_fetch_Result($result, $s, port));
+   $WTIME = enco_rtrim(db_fetch_Result($result, $s, wtime));
+   $PINFO = enco_rtrim(db_fetch_Result($result, $s, pinfo));
+   $ERRDATA = enco_rtrim(db_fetch_Result($result, $s, errdata));
+   $PRINO = enco_rtrim(db_fetch_Result($result, $s, prino));
+   $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
+   $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
+   $FREE3 = enco_rtrim(db_fetch_Result($result, $s, free3));
+   $FREE4 = enco_rtrim(db_fetch_Result($result, $s, free4));
+   $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
    if($PRINO <= 1){
       $pcol = "bgcolor=red";
@@ -150,8 +150,8 @@ while($s < $num){
 
 echo"</table>";
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 echo "\n";
 echo "<font color=red size=1>";
