@@ -35,7 +35,7 @@ echo "</HEAD>";
 
 
 // Cname Bname List 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -43,23 +43,23 @@ if(!$conn){
 
 //  ƻ֥å̾ꥹȺ
 $bname_count = 0;
-$result = pg_query($conn, "select distinct(bname) from userblock;");
+$result = db_query($conn, "select distinct(bname) from userblock;");
 if(!$result){
    print("banem select , bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
-      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
+      $bname_data[$bname_count] = enco_rtrim(db_fetch_Result($result, $bname_count, bname));
+      $result1=db_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
          exit;
          }
-      $num1 = pg_num_rows($result1);
+      $num1 = db_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(db_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -67,25 +67,25 @@ if($num > 0){
 else{
    print("NG ƻ֥å̵Ǥ \n");
    }
-pg_free_result($result);
-pg_free_result($result1);
+db_free_result($result);
+db_free_result($result1);
                                                
 
 $cname_count = 0;
-$result=pg_query($conn,"select distinct(cname) from connection;");
+$result=db_query($conn,"select distinct(cname) from connection;");
 if(!$result){
    print("canem select , bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    while($cname_count < $num){
-      $xcname_data[$cname_count] = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $xcname_data[$cname_count] = enco_rtrim(db_fetch_Result($result, $cname_count, cname));
       $cname_count++;
       }
    }
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 // Cname Bname List 
 
 
