@@ -286,36 +286,36 @@ else{
 
    echo "ΥڡλȤ<a href='./monitor_help.html' target=help>Ȥ</a> 򸫤Ƥ \n";
    }
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
    }
 //  print("$select_data\n");
 //  print("update monitor set ???='???', ???='???' $select_data2\n");
-// $result = pg_query($conn, "select * from monitor where cname='$cname'");
+// $result = db_query($conn, "select * from monitor where cname='$cname'");
 
 
 
 //  ƻ֥å̾ꥹȺ
 $bname_count = 0;
-$result = pg_query($conn, "select distinct(bname) from userblock;");
+$result = db_query($conn, "select distinct(bname) from userblock;");
 if(!$result){
    print("banem select , bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
-      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
+      $bname_data[$bname_count] = enco_rtrim(db_fetch_Result($result, $bname_count, bname));
+      $result1=db_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
          exit;
          }
-      $num1 = pg_num_rows($result1);
+      $num1 = db_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(db_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -323,20 +323,20 @@ if($num > 0){
 else{
    print("NG ƻ֥å̵Ǥ \n");
    }
-pg_free_result($result);
-pg_free_result($result1);
+db_free_result($result);
+db_free_result($result1);
 
 
 
 
 
-$result = pg_query($conn, $select_data);
+$result = db_query($conn, $select_data);
 if(!$result){
    print("bud query\n");
    exit;
    }
 
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
 
    if(0 == strcmp("on", $csv_ch)){
@@ -388,22 +388,22 @@ if($num > 0){
       }
 
    while($s < $num){
-      $COME = enco_rtrim(pg_fetch_Result($result, $s, come));
-      $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-      $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
-      $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
-      $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
-      $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
-      $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-      $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
-      $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
-      $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
-      $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
-      $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
-      $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
-      $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
-      $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
-      $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
+      $COME = enco_rtrim(db_fetch_Result($result, $s, come));
+      $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+      $MONITOR = enco_rtrim(db_fetch_Result($result, $s, monitor));
+      $SIGN = enco_rtrim(db_fetch_Result($result, $s, sign));
+      $PROTO = enco_rtrim(db_fetch_Result($result, $s, proto));
+      $COM = enco_rtrim(db_fetch_Result($result, $s, com));
+      $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
+      $PORT = enco_rtrim(db_fetch_Result($result, $s, port));
+      $WTIME = enco_rtrim(db_fetch_Result($result, $s, wtime));
+      $PINFO = enco_rtrim(db_fetch_Result($result, $s, pinfo));
+      $PRINO = enco_rtrim(db_fetch_Result($result, $s, prino));
+      $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
+      $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
+      $FREE3 = enco_rtrim(db_fetch_Result($result, $s, free3));
+      $FREE4 = enco_rtrim(db_fetch_Result($result, $s, free4));
+      $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
 
       if(0 == strcmp($COME, "ON")){
@@ -625,8 +625,8 @@ else{
    $FREE4 = $block;
    }
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 ?>
 
