@@ -111,7 +111,7 @@ print("\n");
 print($select_data);
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -138,19 +138,19 @@ for($count=1; $count < 13; $count++){
 
    $select_data_2 = " and mo='$count'";
 
-   $result = pg_query($conn, "$select_data$select_data_2");
+   $result = db_query($conn, "$select_data$select_data_2");
    if(!$result){
       print("bud query\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
 
    if($maxlen < $num){
       $maxlen = $num;
       }
    $rldata[$count] = $num;
 
-   pg_free_result($result);
+   db_free_result($result);
    $num = 0;
    }
 
@@ -186,7 +186,7 @@ for($count=1; $count < 13; $count++){
 echo "</table>";
 echo "</font>";
 
-pg_Close($conn);
+db_Close($conn);
 
 ?>
 </pre>
