@@ -9,7 +9,6 @@ if(0 > ninsyou_check(5)){
 
 
 
-
 echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
 echo "<HTML>";
 echo "<HEAD>";
@@ -46,19 +45,19 @@ else{
 print("Խˡ<a target=edit_help href='./setupmonitor.html'></a>ǧƤ\n");
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
    }
 
-$result = pg_query($conn, "select * from monitor where uno='$uno'");
+$result = db_query($conn, "select * from monitor where uno='$uno'");
 if(!$result){
    print("bud query\n");
    exit;
    }
 
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data\n");
    exit;
@@ -69,48 +68,48 @@ print("\n\n");
 echo "<TABLE border=3  WIDTH=50% height=10% BGCOLOR=#e6e8fa>";
 
 while($s < $num){
-   $COME = enco_rtrim(pg_fetch_Result($result, $s, come));
-   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-   $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
-   $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
-   $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
-   $COM = pg_fetch_Result($result, $s, com);
-   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-   $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
-   $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
-   $PINFO = pg_fetch_Result($result, $s, pinfo);
-   $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
-   $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
-   $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
-   $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
-   $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
-   $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
+   $COME = enco_rtrim(db_fetch_Result($result, $s, come));
+   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+   $MONITOR = enco_rtrim(db_fetch_Result($result, $s, monitor));
+   $SIGN = enco_rtrim(db_fetch_Result($result, $s, sign));
+   $PROTO = enco_rtrim(db_fetch_Result($result, $s, proto));
+   $COM = db_fetch_Result($result, $s, com);
+   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
+   $PORT = enco_rtrim(db_fetch_Result($result, $s, port));
+   $WTIME = enco_rtrim(db_fetch_Result($result, $s, wtime));
+   $PINFO = db_fetch_Result($result, $s, pinfo);
+   $PRINO = enco_rtrim(db_fetch_Result($result, $s, prino));
+   $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
+   $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
+   $FREE3 = enco_rtrim(db_fetch_Result($result, $s, free3));
+   $FREE4 = enco_rtrim(db_fetch_Result($result, $s, free4));
+   $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
    $s++;
    }
-pg_free_result($result);
+db_free_result($result);
 
 
 
 //  ƻ֥å̾ꥹȺ
 $bname_count = 0;
-$result = pg_query($conn, "select distinct(bname) from userblock;");
+$result = db_query($conn, "select distinct(bname) from userblock;");
 if(!$result){
    print("banem select , bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
    while($bname_count < $num){
-      $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
-      $result1=pg_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
+      $bname_data[$bname_count] = enco_rtrim(db_fetch_Result($result, $bname_count, bname));
+      $result1=db_query($conn,"select distinct(cname) from userblock where bname='$bname_data[$bname_count]';");
       if(!$result1){
          print("bname , canem select , bud query\n");
          exit;
          }
-      $num1 = pg_num_rows($result1);
+      $num1 = db_num_rows($result1);
       if($num1 > 0){
-         $cname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result1, 0, cname));
+         $cname_data[$bname_count] = enco_rtrim(db_fetch_Result($result1, 0, cname));
          }
       $bname_count++;
       }
@@ -118,8 +117,8 @@ if($num > 0){
 else{
    print("NG ƻ֥å̵Ǥ \n");
    }
-pg_free_result($result);
-pg_free_result($result1);
+db_free_result($result);
+db_free_result($result1);
 
 
 
@@ -419,8 +418,8 @@ else{
    }
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 print("</font>");
 
