@@ -7,8 +7,6 @@ if(0 > ninsyou_check(5)){
    exit;
    }
 
-require("./socket.inc");
-require("./list_file_upload.inc");
 
 
 echo "<!DOCTYP:pserver:cvs@dhcvs.ms-n.com:/usr/home/cvsE HTML PUBLIC '-//W3C//DTD HTML 4.01 Transitional//EN'>";
@@ -27,21 +25,21 @@ print("<tr><td align=left><font color='ffffff'><b>ƻ -> Խ</b></font></td></tr>\
 print("</table>\n");
 
 
-$COME = $_GET["COME"];
-$CNAME = $_GET["CNAME"];
-$MONITOR = $_GET["MONITOR"];
-$SIGN = $_GET["SIGN"];
-$PROTO = $_GET["PROTO"];
-$COM = $_GET["COM"];
-$CIP = $_GET["CIP"];
-$PORT = $_GET["PORT"];
-$WTIME = $_GET["WTIME"];
-$PINFO = $_GET["PINFO"];
-$PRINO = $_GET["PRINO"];
-$FREE1 = $_GET["FREE1"];
-$FREE2 = $_GET["FREE2"];
-$FREE3 = $_GET["FREE3"];
-$FREE4 = $_GET["FREE4"];
+$COME = enco($_GET["COME"]);
+$CNAME = enco($_GET["CNAME"]);
+$MONITOR = enco($_GET["MONITOR"]);
+$SIGN = enco($_GET["SIGN"]);
+$PROTO = enco($_GET["PROTO"]);
+$COM = enco($_GET["COM"]);
+$CIP = enco($_GET["CIP"]);
+$PORT = enco($_GET["PORT"]);
+$WTIME = enco($_GET["WTIME"]);
+$PINFO = enco($_GET["PINFO"]);
+$PRINO = enco($_GET["PRINO"]);
+$FREE1 = enco($_GET["FREE1"]);
+$FREE2 = enco($_GET["FREE2"]);
+$FREE3 = enco($_GET["FREE3"]);
+$FREE4 = enco($_GET["FREE4"]);
 
 if(0 == strlen($COME)){ $COME = "OFF"; }
 if(0 == strlen($FREE4)){
