@@ -351,19 +351,19 @@ print("\n");
 print("$select_data \n");
 // print("delete from errlog where $select_data2 \n");
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
    }
 
-$result = pg_query($conn, $select_data);
+$result = db_query($conn, $select_data);
 if(!$result){
    print("bud query\n");
    exit;
    }
 
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 
 
 
@@ -398,30 +398,30 @@ if(0 == strcmp($csv_ch, "on")){
 
    while($s < $num && $s < $stop){
 
-      $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-      $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-      $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
-      $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
-      $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
-      $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
-      $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
-      $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
-      $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
-      $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
-      $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
-      $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
-      $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
-      $CINFO = enco_rtrim(pg_fetch_Result($result, $s, cinfo));
-      $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
-      $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
-      $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
-      $ERRDATA = enco_rtrim(pg_fetch_Result($result, $s, errdata));
-      $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
-      $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
-      $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
-      $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
-      $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
-      $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
+      $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
+      $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+      $MONITOR = enco_rtrim(db_fetch_Result($result, $s, monitor));
+      $UCT = enco_rtrim(db_fetch_Result($result, $s, uct));
+      $YE = enco_rtrim(db_fetch_Result($result, $s, ye));
+      $MO = enco_rtrim(db_fetch_Result($result, $s, mo));
+      $DA = enco_rtrim(db_fetch_Result($result, $s, da));
+      $HA = enco_rtrim(db_fetch_Result($result, $s, ha));
+      $MI = enco_rtrim(db_fetch_Result($result, $s, mi));
+      $SE = enco_rtrim(db_fetch_Result($result, $s, se));
+      $SIGN = enco_rtrim(db_fetch_Result($result, $s, sign));
+      $PROTO = enco_rtrim(db_fetch_Result($result, $s, proto));
+      $COM = enco_rtrim(db_fetch_Result($result, $s, com));
+      $CINFO = enco_rtrim(db_fetch_Result($result, $s, cinfo));
+      $PORT = enco_rtrim(db_fetch_Result($result, $s, port));
+      $WTIME = enco_rtrim(db_fetch_Result($result, $s, wtime));
+      $PINFO = enco_rtrim(db_fetch_Result($result, $s, pinfo));
+      $ERRDATA = enco_rtrim(db_fetch_Result($result, $s, errdata));
+      $PRINO = enco_rtrim(db_fetch_Result($result, $s, prino));
+      $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
+      $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
+      $FREE3 = enco_rtrim(db_fetch_Result($result, $s, free3));
+      $FREE4 = enco_rtrim(db_fetch_Result($result, $s, free4));
+      $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
       $ERR = strtr($ERRDATA, "\n", "||");
       $SS = $s + 1;
@@ -456,30 +456,30 @@ else {
    echo "</tr>";
 
    while($s < $num && $s < $stop){
-      $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
-      $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-      $MONITOR = enco_rtrim(pg_fetch_Result($result, $s, monitor));
-      $UCT = enco_rtrim(pg_fetch_Result($result, $s, uct));
-      $YE = enco_rtrim(pg_fetch_Result($result, $s, ye));
-      $MO = enco_rtrim(pg_fetch_Result($result, $s, mo));
-      $DA = enco_rtrim(pg_fetch_Result($result, $s, da));
-      $HA = enco_rtrim(pg_fetch_Result($result, $s, ha));
-      $MI = enco_rtrim(pg_fetch_Result($result, $s, mi));
-      $SE = enco_rtrim(pg_fetch_Result($result, $s, se));
-      $SIGN = enco_rtrim(pg_fetch_Result($result, $s, sign));
-      $PROTO = enco_rtrim(pg_fetch_Result($result, $s, proto));
-      $COM = enco_rtrim(pg_fetch_Result($result, $s, com));
-      $CINFO = enco_rtrim(pg_fetch_Result($result, $s, cinfo));
-      $PORT = enco_rtrim(pg_fetch_Result($result, $s, port));
-      $WTIME = enco_rtrim(pg_fetch_Result($result, $s, wtime));
-      $PINFO = enco_rtrim(pg_fetch_Result($result, $s, pinfo));
-      $ERRDATA = enco_rtrim(pg_fetch_Result($result, $s, errdata));
-      $PRINO = enco_rtrim(pg_fetch_Result($result, $s, prino));
-      $FREE1 = enco_rtrim(pg_fetch_Result($result, $s, free1));
-      $FREE2 = enco_rtrim(pg_fetch_Result($result, $s, free2));
-      $FREE3 = enco_rtrim(pg_fetch_Result($result, $s, free3));
-      $FREE4 = enco_rtrim(pg_fetch_Result($result, $s, free4));
-      $UNO = enco_rtrim(pg_fetch_Result($result, $s, uno));
+      $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
+      $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+      $MONITOR = enco_rtrim(db_fetch_Result($result, $s, monitor));
+      $UCT = enco_rtrim(db_fetch_Result($result, $s, uct));
+      $YE = enco_rtrim(db_fetch_Result($result, $s, ye));
+      $MO = enco_rtrim(db_fetch_Result($result, $s, mo));
+      $DA = enco_rtrim(db_fetch_Result($result, $s, da));
+      $HA = enco_rtrim(db_fetch_Result($result, $s, ha));
+      $MI = enco_rtrim(db_fetch_Result($result, $s, mi));
+      $SE = enco_rtrim(db_fetch_Result($result, $s, se));
+      $SIGN = enco_rtrim(db_fetch_Result($result, $s, sign));
+      $PROTO = enco_rtrim(db_fetch_Result($result, $s, proto));
+      $COM = enco_rtrim(db_fetch_Result($result, $s, com));
+      $CINFO = enco_rtrim(db_fetch_Result($result, $s, cinfo));
+      $PORT = enco_rtrim(db_fetch_Result($result, $s, port));
+      $WTIME = enco_rtrim(db_fetch_Result($result, $s, wtime));
+      $PINFO = enco_rtrim(db_fetch_Result($result, $s, pinfo));
+      $ERRDATA = enco_rtrim(db_fetch_Result($result, $s, errdata));
+      $PRINO = enco_rtrim(db_fetch_Result($result, $s, prino));
+      $FREE1 = enco_rtrim(db_fetch_Result($result, $s, free1));
+      $FREE2 = enco_rtrim(db_fetch_Result($result, $s, free2));
+      $FREE3 = enco_rtrim(db_fetch_Result($result, $s, free3));
+      $FREE4 = enco_rtrim(db_fetch_Result($result, $s, free4));
+      $UNO = enco_rtrim(db_fetch_Result($result, $s, uno));
 
       if($PRINO <= 1){
          $pcol = "bgcolor=red";
@@ -601,8 +601,8 @@ echo"</table>";
 
 print("</font>");
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 ?>
 </pre>
