@@ -97,7 +97,7 @@ if(0 >= strlen($CNAME_NEW)){
 
 
 // DB³
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -105,39 +105,39 @@ if(!$conn){
 
 if(0 < $MAX){
    $count = 0;
-   $result=pg_query($conn,"select cname from monitor where free4='$FREE4';");
+   $result=db_query($conn,"select cname from monitor where free4='$FREE4';");
    if(!$result){
       print("canem select , bud query\n");
       exit;
       }
-   $maxnum = pg_num_rows($result);
+   $maxnum = db_num_rows($result);
    if($maxnum >= $MAX){
       print("MAX $MAX \n");
       exit;
       }
 
-   pg_free_result($result);
+   db_free_result($result);
    }
 
 
 
 
 // ѹΥ֥å̾ȥ饤̾򵭲ޤ
-$result = pg_query($conn, "select * from monitor where uno='$UNO'");
+$result = db_query($conn, "select * from monitor where uno='$UNO'");
 if(!$result){
    print("bud query set\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num > 0){
-   $FREE4_OLD = enco_rtrim(pg_fetch_Result($result, $s, free4));
-   $CNAME_OLD = enco_rtrim(pg_fetch_Result($result, $s, cname));
+   $FREE4_OLD = enco_rtrim(db_fetch_Result($result, $s, free4));
+   $CNAME_OLD = enco_rtrim(db_fetch_Result($result, $s, cname));
    }
 else{
    print("not data?\n");
    exit;
    }
-pg_free_result($result);
+db_free_result($result);
 
 
 
@@ -145,7 +145,7 @@ if(0 < strlen($GEN)){
 
    // UPDATE ʤΤǥåץǡȤޤ
    if($STATUS == "UPDATE"){
-      $result = pg_query($conn, "update monitor set
+      $result = db_query($conn, "update monitor set
        come='$COME',
        cname='$CNAME_NEW',
        monitor='$MONITOR',
@@ -167,13 +167,30 @@ if(0 < strlen($GEN)){
          print("bud query set\n");
          exit;
          }
-      pg_free_result($result);
+      db_free_result($result);
       print("ѹDBȿǤޤ\n");
       }
 
   // UPDATEǤϤʤΤǡɲäޤ
    else{
-      $result = pg_query($conn, "insert into monitor values (
+      $result = db_query($conn, "insert into monitor
+        (
+        come,
+        cname,
+        monitor,
+        sign,
+        proto,
+        com,
+        cip,
+        port,
+        wtime,
+        pinfo,
+        prino,
+        free1,
+        free2,
+        free3,
+        free4
+        ) values (
        '$COME',
        '$CNAME_NEW',
        '$MONITOR',
@@ -209,8 +226,8 @@ if(0 < strlen($GEN)){
    }
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 ?>
 
