@@ -48,7 +48,7 @@ if(0 == strlen($CNAME)){
    }
 
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "NG not connection!<br>";
    exit;
@@ -58,20 +58,20 @@ print("$CNAME --> $CNAME2 \n");
 
 
 if(0 < strlen($CNAME2)){
-   $result = pg_query($conn, "select * from connection where cname='$CNAME2'");
+   $result = db_query($conn, "select * from connection where cname='$CNAME2'");
    if($result){
-      $num = pg_num_rows($result);
+      $num = db_num_rows($result);
       if($num > 0){
 
          print("OK connection ưԤޤ\n");
 
-         $result=pg_query($conn,
+         $result=db_query($conn,
            "update userblock set cname='$CNAME2' where cname='$CNAME'");
          if(!$conn){
             echo "NG userblock ưޤǤ<br>";
             exit;
             }
-         $result=pg_query($conn,
+         $result=db_query($conn,
            "update monitor set cname='$CNAME2' where cname='$CNAME'");
          if(!$conn){
             echo "NG monitor ưޤǤ<br>";
@@ -91,7 +91,7 @@ if(0 < strlen($CNAME2)){
    }
 
 
-$result = pg_query($conn, "delete from connection where cname='$CNAME'");
+$result = db_query($conn, "delete from connection where cname='$CNAME'");
 if(!$result){
    print("NG connection Ǥޤ\n");
    exit;
@@ -99,19 +99,19 @@ if(!$result){
 
 
 
-$result = pg_query($conn, "delete from monitor where cname='$CNAME'");
+$result = db_query($conn, "delete from monitor where cname='$CNAME'");
 if(!$result){
    print("NG monitor Ǥޤ\n");
    exit;
    }
 
-$result = pg_query($conn, "delete from userblock where cname='$CNAME'");
+$result = db_query($conn, "delete from userblock where cname='$CNAME'");
 if(!$result){
    print("NG userblock Ǥޤ\n");
    exit;
    }
 
-$result = pg_query($conn, "delete from config where c_name='$CNAME'");
+$result = db_query($conn, "delete from config where c_name='$CNAME'");
 if(!$result){
    print("NG config Ǥޤ\n");
    exit;
@@ -145,12 +145,12 @@ echo " \n";
 
 
 $conf_file = "/usr/local/zither/conf/neg.conf";
-$result = pg_query($conn, "select * from connection");
+$result = db_query($conn, "select * from connection");
 if(!$result){
    print("bud query conection\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data conection\n");
    exit;
@@ -161,8 +161,8 @@ if(($fp = fopen($conf_file, "w+"))==NULL){
    }
 $s = 0;
 while($s < $num){
-   $CNAME = enco_rtrim(pg_fetch_Result($result, $s, cname));
-   $CIP = enco_rtrim(pg_fetch_Result($result, $s, cip));
+   $CNAME = enco_rtrim(db_fetch_Result($result, $s, cname));
+   $CIP = enco_rtrim(db_fetch_Result($result, $s, cip));
    fwrite($fp, "$CNAME:$CIP\n");
    print("$CNAME:$CIP\n");
    $s++;
@@ -174,19 +174,19 @@ echo " \n";
 
 if(0 < strlen($GEN)){
    $s = 0;
-   $result = pg_query($conn, "select distinct(server) from connection;");
+   $result = db_query($conn, "select distinct(server) from connection;");
    if(!$result){
       print("bud query\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num <= 0){
       print("no data\n");
       exit;
       }
    else{
       while($s < $num){
-         $SERVER = enco_rtrim(pg_fetch_Result($result, $s, server));
+         $SERVER = enco_rtrim(db_fetch_Result($result, $s, server));
          print("$SERVER $my_web_ip ");
          if(0 != strcmp($SERVER, $my_web_ip)){
 
@@ -208,8 +208,8 @@ if(0 < strlen($GEN)){
 
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 
 
