@@ -83,7 +83,7 @@ $EE="=";
 
 // ----- DB ³ ----//
 
-$conn = Pg_connect("hostaddr='$pg_connect_ip' port='5432' dbname='zither' connect_timeout='8'");
+$conn = db_connect();
 if(!$conn){
    echo "not connection!<br>";
    exit;
@@ -189,15 +189,15 @@ if(0 != strlen($CNAME)){
    print("狼 ƻ֥å̾ꥹȺ \n");
 
    $bname_count = 0;
-   $result = pg_query($conn, "select distinct(bname) from userblock $select_get;");
+   $result = db_query($conn, "select distinct(bname) from userblock $select_get;");
    if(!$result){
       print("banem select , bud query\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num > 0){
       while($bname_count < $num){
-         $bname_data[$bname_count] = enco_rtrim(pg_fetch_Result($result, $bname_count, bname));
+         $bname_data[$bname_count] = enco_rtrim(db_fetch_Result($result, $bname_count, bname));
          print("ֹ ($bname_count) 狼鸡BNAME= $bname_data[$bname_count] ꥹȤɲ\n");
          $bname_count++;
          }
@@ -205,7 +205,7 @@ if(0 != strlen($CNAME)){
    else{
       print("NG ƻ֥å̵Ǥ \n");
       }
-   pg_free_result($result);
+   db_free_result($result);
 
    }
 
@@ -230,12 +230,12 @@ print("UPDATE COMMAND = $select_data\n");
 
 print("ѹCNAMEꥹ \n");
 
-$result = pg_query($conn, "select distinct(cname) from userblock $select_get");
+$result = db_query($conn, "select distinct(cname) from userblock $select_get");
 if(!$result){
    print("NG bud query\n");
    exit;
    }
-$num = pg_num_rows($result);
+$num = db_num_rows($result);
 if($num <= 0){
    print("no data\n");
    exit;
@@ -243,7 +243,7 @@ if($num <= 0){
 else{
    $cname_count =0;
    while($cname_count < $num){
-      $cname_data[$cname_count]  = enco_rtrim(pg_fetch_Result($result, $cname_count, cname));
+      $cname_data[$cname_count]  = enco_rtrim(db_fetch_Result($result, $cname_count, cname));
       print("ֹ ($cname_count) 狼ѹ饤Ȥꥹ CNAME= $cname_data[$cname_count]");
       print("\n");
       $cname_count++;
@@ -264,13 +264,13 @@ if(0 == strlen($select_data)){
    exit;
    }
 else{
-   $result = pg_query($conn, "$select_data");
+   $result = db_query($conn, "$select_data");
    print("ƻѹ夦Ǥ select_data = $select_data\n");
    if(!$result){
       print("NG bud query $select_data\n");
       exit;
       }
-   $num = pg_num_rows($result);
+   $num = db_num_rows($result);
    if($num < 0){
       print("NG ƻ֥å꤬ѹƤޤ\n");
       exit;
@@ -287,17 +287,17 @@ if($new_cname_ok == 1){
       print("CNAMEѹ BNAME= $bname_data[$count] ޤƻΥ饤Ȥ $CNAME ѹޤ$count $qudata");
       print("\n");
 
-      $result = pg_query($conn, $qudata);
+      $result = db_query($conn, $qudata);
       if(!$result){
          print("NG bud query $select_data\n");
          exit;
          }
-      $num = pg_num_rows($result);
+      $num = db_num_rows($result);
       if($num < 0){
          print("NG monitor DB ƻ꤬ѹƤޤ\n");
          exit;
          }
-      pg_free_result($result);
+      db_free_result($result);
       }
    }
 
@@ -330,8 +330,8 @@ else{
 
 
 
-pg_free_result($result);
-pg_Close($conn);
+db_free_result($result);
+db_Close($conn);
 
 ?>
 
