@@ -38,7 +38,7 @@
      };
 
 
-   int file_comp(char * chB);
+   int file_comp(char * chB, char * comp_path);
    int comp_private_malloc_set(private_data_comp *, int);
    int comp_private_malloc_free(private_data_comp *, int);
    int conf_seting(private_data_comp *, char *);
