@@ -4,8 +4,11 @@
 #include<string.h>
 #include<stdlib.h>
 #include<unistd.h>
+#include<pthread.h>
 
 #include"sitar.h"
+#include<almemsys/almemsys.h>
+
 
 extern global_data_t gd;
 
