@@ -1,12 +1,11 @@
-// resolv.c
-// $Id: resolv.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
-// masashi shimakura
 
-#include<stdio.h>
-#include<stdlib.h>
 #include<arpa/inet.h>
+#include<netinet/in.h>
 
 #include<netdb.h>
+#include<stdio.h>
+#include<stdlib.h>
+
 
 
 unsigned long resolvename(char *name)
