@@ -2,9 +2,16 @@
 #include<stdio.h>
 #include<stdlib.h>
 #include<string.h>
+#include<netdb.h>
 #include<unistd.h>
+#include<sys/socket.h>
+#include<netinet/in_systm.h>
+#include<netinet/in.h>
+#include<netinet/ip.h>
+#include<arpa/inet.h>
 #include<fcntl.h>
 
+#include<sys/stat.h>
 #include<errno.h>
 
 #include"sitar_scan.h"
@@ -13,6 +20,8 @@
 #include"jpreturn.h"
 
 
+
+
 /* 0-> dhw exc command line 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_smtp_connect(int, char *, char *, int);
 */
@@ -75,13 +84,13 @@ ip_addr = inet_ntoa(my_addr.sin_addr);
 printf("DHW: scan_dhw_connect(2): connect start %s %s %d\n", url_dom, ip_addr, port);
 #endif
 
-// 非同期通信の開始、TCPポートにコネクション
+// 非同期通\Bぃ開@、TCPポートにゃEネクゃLッ@ッE
 fcntl(sk, F_SETFL, O_NONBLOCK);
 re = connect(sk, (struct sockaddr *)(long int)&my_addr, sizeof(my_addr));
 
-// 速攻で繋がった場合の処理
+// 速攻ぃ@繋がぁvた堃G合の凃
 if(re >= 0){
-   // 非同期通信から同期通信に
+   // 非同期通\Bから同期通\BぃH
    fcntl(sk, F_SETFL, 0);
    backdata=safe_sprintf(backdata,BUF_MAX,
     "URL=%s Port=%d %s", url_dom, port, SOCK_5);
@@ -91,7 +100,7 @@ if(re >= 0){
    goto notselect;
    }
 
-// errnoが EINPROGRESS な場合
+// errnoが EINPROGRESS ぃF堃G
 if(errno == EINPROGRESS){
    tv.tv_sec = timeout;
    tv.tv_usec = 0;
@@ -99,14 +108,14 @@ if(errno == EINPROGRESS){
       FD_ZERO(&rfds);
       FD_SET(sk, &rfds);
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
-      // select 異常終了
+      // select 畁|布N終R
       if(retval < 0){
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SOCK_5);
          #ifdef DHW_BUG
          printf("DHW: scan_dhw_connect(3): select err BREAK- %d - %s\n", retval, backdata);
          #endif
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = -1;
@@ -114,7 +123,7 @@ if(errno == EINPROGRESS){
          free(senddata);
          return backdata;
          }
-      // select のタイムアウト
+      // select ぃゃ\めAムめuゃ
       else if(retval == 0){
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SOCK_5);
@@ -122,7 +131,7 @@ if(errno == EINPROGRESS){
          printf("DHW: scan_dhw_connect(4): select time out BREAK- %d - %s\n",
            retval, backdata);
          #endif
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = -1;
@@ -130,7 +139,7 @@ if(errno == EINPROGRESS){
          free(senddata);
          return backdata;
          }
-      // 時間内に接続出来たのでLoopOut
+      // 時間内に掁E続出杁Eたのぃ@LoopOut
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s", url_dom, port, SOCK_3);
@@ -142,13 +151,13 @@ if(errno == EINPROGRESS){
       }
 
 
-   // 非同期通信から同期通信に
+   // 非同期通\Bから同期通\BぃH
    fcntl(sk, F_SETFL, 0);
 
    // select を省いたGOTO
    notselect :;
 
-   // ソケットに関するペンディングエラーを返す
+   // ゃXゃAットぃH閁uするペンディッEめ|ゃBッDッVを\す
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
       backdata=safe_sprintf(backdata,BUF_MAX,
        "URL=%s Port=%d %s", url_dom, port, SOCK_13);
@@ -163,7 +172,7 @@ if(errno == EINPROGRESS){
       }
 
    else{
-      // エラーがある
+      // ゃBッDッVがあ
       if(retval){
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s: TCP %s", url_dom, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
@@ -177,7 +186,7 @@ if(errno == EINPROGRESS){
          return backdata;
          }
 
-      // エラーが無い場合
+      // ゃBッDッVが無い堃G
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s", url_dom, port, SOCK_3);
@@ -189,10 +198,10 @@ if(errno == EINPROGRESS){
          printf("DHW: scan_dhw_connect(9): set_request*send-- %s --\n", senddata);
          #endif 
 
-         // 再度非同期通信の開始
+         // 再R非同期通\Bぃ開@
          fcntl(sk, F_SETFL, O_NONBLOCK);
 
-         // DHW コマンドの送信
+         // DHW ゃEマンドの送\B
          send(sk, senddata, strlen(senddata), 0);
 
          tv.tv_sec = timeout;
@@ -202,14 +211,14 @@ if(errno == EINPROGRESS){
             FD_SET(sk, &rfds);
             retval = select(sk + 1, &rfds, NULL, NULL, &tv);
 
-            // select の異常終了
+            // select ぃ畁|布N終R
             if(retval < 0){
                #ifdef DHW_BUG
                printf("DHW: scan_dhw_connect(10): retval 0 ERR\n");
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
                 "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, URL_2);
-               // 非同期通信から同期通信に
+               // 非同期通\Bから同期通\BぃH
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
@@ -218,14 +227,14 @@ if(errno == EINPROGRESS){
                return backdata;
                }
 
-            // selectのタイムアウト
+            // selectぃゃ\めAムめuゃ
             else if(retval == 0){
                #ifdef DHW_BUG
                printf("DHW: scan_dhw_connect(11): retval 1 ERR\n"); 
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
                 "URL=%s Port=%d %s %s" , url_dom, port, SOCK_16, URL_3);
-               // 非同期通信から同期通信に
+               // 非同期通\Bから同期通\BぃH
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
@@ -234,14 +243,14 @@ if(errno == EINPROGRESS){
                return backdata;
                }
 
-            // select正常
+            // select歁v布N
             else{
                dcount = recv(sk, recvdata, BUF_LEN, 0);
                #ifdef DHW_BUG
                printf("DHW: scan_dhw_connect(12): recv-- %s --\n", recvdata);
                #endif
 
-               // 受信量がゼロ、エラーではない。
+               // 受\B量がゃVッ、エッDッVぃ@ぃbぃFい
                if(dcount < 1){
                   backdata = safe_sprintf(backdata,BUF_MAX,
                     "DHW COMMAND SUCCESS %s" , comand);
@@ -251,7 +260,7 @@ if(errno == EINPROGRESS){
                   #endif
                   }
 
-            // 何らかのエラーを取得
+            // 何らかのゃBッDッVを取
                else{
                ret = -1;
                   #ifdef DHW_BUG
@@ -266,7 +275,7 @@ if(errno == EINPROGRESS){
                #ifdef DHW_BUG
                printf("DHW: scan_dhw_connect(15): %d <2> %s\n", ret, backdata);
                #endif
-               // 非同期通信から同期通信に
+               // 非同期通\Bから同期通\BぃH
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = ret;
@@ -276,9 +285,9 @@ if(errno == EINPROGRESS){
                }
             }
 
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = ret;
@@ -290,8 +299,8 @@ if(errno == EINPROGRESS){
    }
 
 
-// host IP 等が存在すらしない場合の処理
-// 非同期通信から同期通信に
+// host IP 等が存在すらしない堃G合の凃
+// 非同期通\Bから同期通\BぃH
 fcntl(sk, F_SETFL, 0);
 backdata=safe_sprintf(backdata,BUF_MAX,
  "URL=%s Port=%d %s", url_dom, port, SOCK_14);
