@@ -1,23 +1,26 @@
 
 #include<stdio.h>
-//#include<string.h>
+#include<string.h>
 #include<unistd.h>
-//#include<sys/socket.h>
+#include<sys/socket.h>
 #include<sys/time.h>
-//#include<netinet/in_systm.h>
-//#include<netinet/in.h>
-//#include<netinet/ip.h>
+#include<netinet/in_systm.h>
+#include<netinet/in.h>
+#include<netinet/ip.h>
 #include<netinet/ip_icmp.h>
-//#include<arpa/inet.h>
+#include<arpa/inet.h>
 
-//#include<sys/stat.h> 
+#include<sys/stat.h> 
 #include<sys/un.h>
 
 #include"sitar_scan.h"
-//#include"sitar_com.h"
+#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+
+
+
 /* 1-> Ipsddr 2-> return data,, return status code 0=open or=close */
 /* int scan_icmp(char [], char *);
 int make_icmp8_packet(struct icmp *, int, int);
@@ -105,7 +108,7 @@ fd_set select_fd;
 rtt = 0.0;
 i = 0;
 
-// 名前解決
+// 名前见v汃R
 memset((char *)&send_addr, 0, sizeof(struct sockaddr_in));
 send_addr.sin_family = AF_INET;
 
@@ -143,7 +146,7 @@ if((send_sk = socket(AF_INET, SOCK_RAW, IPPROTO_ICMP)) < 0){
    }
 
 
-// ICMP packetの生成 ＆ SEND
+// ICMP packetぃ生成 ＆ SEND
 make_icmp8_packet((struct icmp *)(long int)send_buff, 72, i);
 if(sendto(send_sk, (char *)&send_buff, 72, 0, (struct sockaddr *)(long int)&send_addr, sizeof(send_addr)) < 0){
    backdata=safe_sprintf(backdata, BUF_MAX,"IP=%s %s",
@@ -156,7 +159,7 @@ if(sendto(send_sk, (char *)&send_buff, 72, 0, (struct sockaddr *)(long int)&send
    return backdata;
    }
 
-// select timeout の設定
+// select timeout ぃ訃
 tv.tv_sec = 0;
 tv.tv_usec =(timeout * 100000);
 
@@ -184,12 +187,12 @@ while(1){
    ip = (struct ip *)(long int)recv_buff;
    hlen = ip->ip_hl << 2;
 
-   // 送信元アドレスと自分のアドレスの比較
+   // 送\B元アドレゃPぃB臃F分のめuドレゃPぃ比V
    if(ip->ip_src.s_addr == send_addr.sin_addr.s_addr){
       struct icmp *icmp;
       icmp = (struct icmp *)(long int)(recv_buff + hlen);
 
-      // 戻りパケットの形式がICMP_ECHOREPLYの場合
+      // 戃TりパゃAットぃ彁u式がICMP_ECHOREPLYぃ堃G
       if(icmp->icmp_type == ICMP_ECHOREPLY){
          gettimeofday(&tv, (struct timezone *)0);
          tvsub(&tv, (struct timeval *)(icmp->icmp_data));
@@ -229,7 +232,7 @@ while(1){
 
          }
 
-      // TYPEがICMO_ECHOで、自分自身宛のエコー要求のパケットである場合w
+      // TYPEがICMO_ECHOぃ@、自分自躃H宛のゃBゃEッV要Aのパケットぃ@ある堃G合w
       else if(icmp->icmp_type == ICMP_ECHO){
          #ifdef ICMP_BUG
          printf("ICMP: scan_icmp(7): RECV RAW type<%d> sendip<%d> inip<%d>\n",
@@ -237,7 +240,7 @@ while(1){
          #endif
          }
 
-      // TYPEがICMP_UNREACHで、ホストに到達出来ない  // ここでは無い
+      // TYPEがICMP_UNREACHぃ@、ホゃPトに刁|達出杁EぃFい  // ここぃ@ぃb焁B
       else if(icmp->icmp_type == ICMP_UNREACH){
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
             inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
@@ -250,7 +253,7 @@ while(1){
          return backdata;
          }
 
-      // TYPEがICMP_TIMXCEED、TTLが0でパケットが破棄されました  // ここでは無い
+      // TYPEがICMP_TIMXCEED、TTLが0ぃ@パケットが砃G棄されました  // ここぃ@ぃb焁B
       else if(icmp->icmp_type == ICMP_UNREACH){
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
             inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
@@ -263,7 +266,7 @@ while(1){
          return backdata;
          }
 
-      // TYPEがそれ以外の場合（もちろんエラー）
+      // TYPEがそれTE外の堃G合VもぁBろんゃBッDッV	
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,"%s :RTT=%7.4fms %s",
             inet_ntoa(*(struct in_addr *)(long int)&(ip->ip_src.s_addr)),
@@ -277,7 +280,7 @@ while(1){
          }
 
       }
-   // 送信元アドレスと自分のアドレスの比較が正しくない
+   // 送\B元アドレゃPぃB臃F分のめuドレゃPぃ比Vが歁vしくぃF
    else{
       #ifdef ICMP_BUG
       printf("ICMP: scan_icmp(11): RECV RAW DATA sendip<%d> inip<%d>\n",
