@@ -1,12 +1,10 @@
-// scan_port.c	
-// $Id: scan_port.c,v 1.2 2007/11/01 05:57:06 sendan Exp $
-// masashi shimakura
-
 
 #include<stdio.h>
 #include<netinet/in.h>
 #include<stdlib.h>
 #include<string.h>
+#include<time.h>
+#include<unistd.h>
 
 #include<pthread.h>
 #include"sitar.h"
@@ -60,7 +58,9 @@ else if((self_memcmp(pd->ch_prot, "SNTP")) == 0){
 else if((self_memcmp(pd->ch_prot, "ICMP")) == 0){
    // 20071220 rip のタイムラグの問題を修正
    pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, 10); // 1回め
+   usleep(100000);
    pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, 10); // 2回め
+   usleep(100000);
    pd->ch_info=scan_icmp(pd->ch_host, pd->ch_info, pd->timeout, &ret, 10); // 3回め
    if(0 == (int)strlen(pd->ch_info)){
       pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
@@ -98,7 +98,9 @@ else if((self_memcmp(pd->ch_prot, "TCP")) == 0){
 else if((self_memcmp(pd->ch_prot, "UDP")) == 0){
 
    info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, 10); // 1回め
+   usleep(100000);
    info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, 10); // 2回め
+   usleep(100000);
    info_swap = scan_icmp(pd->ch_host, info_swap, pd->timeout, &inA, 10); // 3回め
 
    pd->ch_info = scan_udp_connect(pd->port, pd->ch_host, pd->ch_info, pd->timeout, &inB);
@@ -151,34 +153,74 @@ else{
 
 
 
-/* test mode chack */
+// テストとログモードの処理
 if(0 == self_memcmp(pd->ch_plai, "4")){
    out = 4;
    #ifdef SCAN_PORT_DEBUG
    printf("SCAN_PORT: scan_port(): port chack out = %d\n", out);
    #endif
-   }
-
-if(out == 4){
    if(2 > strlen(pd->ch_info)){
       pd->ch_info = safe_memcpy(pd->ch_info, COM_3, BUF_MAX );
       }
    ret = -1;
    }
+else if(0 == self_memcmp(pd->ch_plai, "11")){
+   if(2 > strlen(pd->ch_info)){
+      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
+      }
+   #ifdef SCAN_PORT_DEBUG
+   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
+   #endif
+   if(ret == -1){
+      pd->ch_plai = safe_memcpy(pd->ch_plai, "1", BUF_MAX);
+      }
+   ret = -1;
+   }
+else if(0 == self_memcmp(pd->ch_plai, "12")){
+   if(2 > strlen(pd->ch_info)){
+      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
+      }
+   #ifdef SCAN_PORT_DEBUG
+   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
+   #endif
+   if(ret == -1){
+      pd->ch_plai = safe_memcpy(pd->ch_plai, "2", BUF_MAX);
+      }
+   ret = -1;
+   }
+else if(0 == self_memcmp(pd->ch_plai, "13")){
+   if(2 > strlen(pd->ch_info)){
+      pd->ch_info = safe_memcpy(pd->ch_info, COM_4, BUF_MAX );
+      }
+   #ifdef SCAN_PORT_DEBUG
+   printf("SCAN_PORT: scan_port(): plai = %s ret = %d\n", pd->ch_plai, ret);
+   #endif
+   if(ret == -1){
+      pd->ch_plai = safe_memcpy(pd->ch_plai, "3", BUF_MAX);
+      }
+   ret = -1;
+   }
+
+
+// if(out == 4){
+//    if(2 > strlen(pd->ch_info)){
+//       pd->ch_info = safe_memcpy(pd->ch_info, COM_3, BUF_MAX );
+//       }
+//    ret = -1;
+//    }
 
 /* */
 
-
+// check_statの設定 正か逆かで反転する。
+// 監視の正逆の判断 check_stat == 1 はエラー 0は正常
 if(ret < 0){
 
    if(pd->ch_stat[0] == '0'){
       pd->check_stat = 1;
       }
-
    else if(pd->ch_stat[0] == '1'){
       pd->check_stat = 0;
       }
-
    }
 
 if(ret >= 0){
@@ -186,11 +228,9 @@ if(ret >= 0){
    if(pd->ch_stat[0] == '1'){
       pd->check_stat = 1;
       }
-
    else if(pd->ch_stat[0] == '0'){
       pd->check_stat = 0;
       }
-
    }
 
 
