@@ -1,17 +1,27 @@
 
+
 #include<stdio.h>
 #include<stdlib.h>
 #include<string.h>
+#include<netdb.h>
 #include<unistd.h>
+#include<sys/socket.h>
+#include<netinet/in_systm.h>
+#include<netinet/in.h>
+#include<netinet/ip.h>
+#include<arpa/inet.h>
 #include<fcntl.h>
 
+#include<sys/stat.h>
 #include<errno.h>
 
 #include"sitar_scan.h"
+#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
 
+
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_smtp_connect(int, char *, char *, int);
 */
@@ -117,14 +127,14 @@ ip_addr = inet_ntoa(my_addr.sin_addr);
 printf("SMTP: scan_smtp_connect(0): %s %s %d\n", url_dom, ip_addr, port);
 #endif
 
-// 非同期通信に切り替え、コネクション実行
+// 非同期通\BぃH切り曃\え、コネクゃLッ@ッE実B
 fcntl(sk, F_SETFL, O_NONBLOCK);
 re = connect(sk, (struct sockaddr *)(long int)&my_addr, sizeof(my_addr));
 
 
-// 速攻で繋がった場合の処理
+// 速攻ぃ@繋がぁvた堃G合の凃
 if(re >= 0){
-   // 非同期通信から同期通信に
+   // 非同期通\Bから同期通\BぃH
    fcntl(sk, F_SETFL, 0);
    backdata=safe_sprintf(backdata,BUF_MAX,
     "SMTP=%s Port=%d %s", url_dom, port, SOCK_5);
@@ -135,7 +145,7 @@ if(re >= 0){
    }
 
 
-// errnoが EINPROGRESS な場合
+// errnoが EINPROGRESS ぃF堃G
 if(errno == EINPROGRESS){
    tv.tv_sec = timeout;
    tv.tv_usec = 0;
@@ -143,14 +153,14 @@ if(errno == EINPROGRESS){
       FD_ZERO(&rfds);
       FD_SET(sk, &rfds);
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
-      // selectのタイムアウト
+      // selectぃゃ\めAムめuゃ
       if(retval < 0){
          #ifdef SMTP_BUG
          printf("SMTP: scan_smtp_connect(2): select error BREAK- %d -\n", retval);
          #endif
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SOCK_5);
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = -1;
@@ -164,7 +174,7 @@ if(errno == EINPROGRESS){
          #endif
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SOCK_5);
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = -1;
@@ -172,7 +182,7 @@ if(errno == EINPROGRESS){
          free(senddata);
          return backdata;
          }
-      // 時間内に接続出来たのLoopOut
+      // 時間内に掁E続出杁EたのLoopOut
       else {
          #ifdef SMTP_BUG
          printf("SMTP: scan_smtp_connect(4): select time succes BREAK- %d -\n", retval);
@@ -183,14 +193,14 @@ if(errno == EINPROGRESS){
          }
       }
 
-   // 非同期通信から同期通信に
+   // 非同期通\Bから同期通\BぃH
    fcntl(sk, F_SETFL, 0);
 
    // select を省いたGOTO
    notselect :;
 
 
-   // ソケットに関するペンディングエラーを戻す
+   // ゃXゃAットぃH閁uするペンディッEめ|ゃBッDッVを戻
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
       backdata=safe_sprintf(backdata,BUF_MAX,
        "URL=%s Port=%d %s", url_dom, port, SOCK_13);
@@ -204,7 +214,7 @@ if(errno == EINPROGRESS){
       return backdata;
       }
    else{
-      // エラーがある
+      // ゃBッDッVがあ
       if(retval){
          #ifdef SMTP_BUG
          printf("SMTP: scan_smtp_connect(6): 1 SO_ERROR %d -\n", retval);
@@ -217,7 +227,7 @@ if(errno == EINPROGRESS){
          free(senddata);
          return backdata;
          }
-      // エラーが無い場合
+      // ゃBッDッVが無い堃G
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s", url_dom, port, SOCK_3);
@@ -226,10 +236,10 @@ if(errno == EINPROGRESS){
          printf("SMTP: scan_smtp_connect(7): set_request*send-- %s --\n", senddata);
          #endif 
 
-         // 再度非同期通信の開始
+         // 再R非同期通\Bぃ開@
          fcntl(sk, F_SETFL, O_NONBLOCK);
 
-         // hello localhost の送信
+         // hello localhost ぃ送\B
          send(sk, senddata, strlen(senddata), 0);
 
          tv.tv_sec = timeout;
@@ -238,14 +248,14 @@ if(errno == EINPROGRESS){
             FD_ZERO(&rfds);
             FD_SET(sk, &rfds);
             retval = select(sk + 1, &rfds, NULL, NULL, &tv);
-            // select 異常終了
+            // select 畁|布N終R
             if(retval < 0){
                #ifdef SMTP_BUG
                printf("SMTP: scan_smtp_connect(8): retval 0 ERR ===\n");
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
                 "URL=%s Port=%d %s %s", url_dom, port, SOCK_15, SMTP_2);
-               // 非同期通信から同期通信に
+               // 非同期通\Bから同期通\BぃH
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
@@ -253,14 +263,14 @@ if(errno == EINPROGRESS){
                free(senddata);
                return backdata;
                }
-            // select のタイムアウト
+            // select ぃゃ\めAムめuゃ
             else if(retval == 0){
                #ifdef SMTP_BUG
                printf("SMTP: scan_smtp_connect(9): retval 1 ERR\n"); 
                #endif 
                backdata=safe_sprintf(backdata,BUF_MAX,
                 "URL=%s Port=%d %s %s", url_dom, port, SOCK_16, SMTP_3);
-               // 非同期通信から同期通信に
+               // 非同期通\Bから同期通\BぃH
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = -1;
@@ -273,20 +283,20 @@ if(errno == EINPROGRESS){
                #ifdef SMTP_BUG
                printf("SMTP: scan_smtp_connect(10): recv-- %s --\n", recvdata);
                #endif
-               // 受信量が異常
+               // 受\B量が畁|布N
                if(dcount < 1){
                   backdata = safe_sprintf(backdata,BUF_MAX,
                    "URL=%s Port=%d %s"
                    , url_dom, port, SMTP_2);
                   ret = -1;
                   }
-               // 受信量は正常
+               // 受\B量は歁v布N
                else{
                   senddata = (char *)realloc(senddata, ((int)strlen(recvdata) + 10) * sizeof(char));
                   ch_char(recvdata, senddata);
                   swap_mem(senddata, '\n', ' ', (int)strlen(senddata));
                   ret = check_smrecvdata(recvdata);
-                  // 受信ステータスが200番だいでない
+                  // 受\BゃPテーゃ\ゃPが200畃FだいでぃF
                   if(ret < 0){
                      backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", SMTP_1, senddata);
                      #ifdef SMTP_BUG
@@ -294,7 +304,7 @@ if(errno == EINPROGRESS){
                        ret,*pst, recvdata, backdata);
                      #endif
                      }
-                  // 受信ステータスが200番だいです。
+                  // 受\BゃPテーゃ\ゃPが200畃Fだいです
                   else{
                      backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", SMTP_4, senddata);
                      #ifdef SMTP_BUG
@@ -303,7 +313,7 @@ if(errno == EINPROGRESS){
                      #endif
                      }
                   }
-               // 非同期通信から同期通信に
+               // 非同期通\Bから同期通\BぃH
                fcntl(sk, F_SETFL, 0);
                close(sk);
                * pst = ret;
@@ -313,7 +323,7 @@ if(errno == EINPROGRESS){
                }
             }
 
-         // 非同期通信から同期通信に
+         // 非同期通\Bから同期通\BぃH
          fcntl(sk, F_SETFL, 0);
          close(sk);
          * pst = ret;
@@ -324,8 +334,8 @@ if(errno == EINPROGRESS){
       }
    }
 
-// host IP 等が存在すらしない場合の処理
-// 非同期通信から同期通信に
+// host IP 等が存在すらしない堃G合の凃
+// 非同期通\Bから同期通\BぃH
 fcntl(sk, F_SETFL, 0);
 backdata=safe_sprintf(backdata,BUF_MAX,
  "URL=%s Port=%d %s", url_dom, port, SOCK_14);
