@@ -1,15 +1,22 @@
-
 #include<stdio.h>
 #include<string.h>
 #include<unistd.h>
+#include<sys/socket.h>
+#include<netinet/in_systm.h>
+#include<netinet/in.h>
+#include<netinet/ip.h>
 #include<fcntl.h>
+#include<arpa/inet.h>
 
+#include<sys/stat.h>
 #include<errno.h>
 
 #include"sitar_scan.h"
+#include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_tcp_connect(int, char *, char *, int);
 */
@@ -64,19 +71,19 @@ printf("TCP: scan_tcp_connetc(3): start TCPCHECK host<%s> ip<%s>\n", ip_addr2, i
 #endif
 
 
-// 非同期でTCPポートにコネクション
+// 非同期でTCPポートにゃEネクゃLッ@ッE
 fcntl(sk, F_SETFL, O_NONBLOCK);
 re = connect(sk, (struct sockaddr *)(long)&my_addr, sizeof(my_addr));
 
 
-// 速攻で確立した場合
+// 速攻ぃ@碃R立した堃G
 if(re >= 0){
    backdata=safe_sprintf(backdata,BUF_MAX,
     "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_3);
    #ifdef TCP_BUG
    printf("TCP: scan_tcp_connect(4): CONNECT SUCCESS %s\n", backdata);
    #endif
-   // 非同期通信から同期通信に
+   // 非同期通\Bから同期通\BぃH
    fcntl(sk, F_SETFL, 0);
    close(sk);
    * stat = 0;
@@ -84,7 +91,7 @@ if(re >= 0){
    }
 
 
-// errnoが EINPROGRESS の場合はselectで待つ
+// errnoが EINPROGRESS ぃ堃G合はselectぃ@待つ
 if(errno == EINPROGRESS){
    tv.tv_sec = timeout;
    tv.tv_usec = 0;
@@ -93,7 +100,7 @@ if(errno == EINPROGRESS){
       FD_ZERO(&rfds);
       FD_SET(sk, &rfds);
       retval = select(sk + 1, NULL, &rfds, NULL, &tv);
-      // select エラー
+      // select ゃBッDッV
       if(retval < 0){
          backdata=safe_sprintf(backdata,BUF_MAX,
           "IP=%s Port=%d %s %s", ip_addr, port, SOCK_15, SOCK_5);
@@ -105,7 +112,7 @@ if(errno == EINPROGRESS){
          * stat = -1;
          return backdata;
          }
-      // select time out です
+      // select time out ぃ@
       else if(retval == 0){
          backdata=safe_sprintf(backdata,BUF_MAX,
           "IP=%s Port=%d %s %s", ip_addr, port, SOCK_16, SOCK_5);
@@ -117,7 +124,7 @@ if(errno == EINPROGRESS){
          * stat = -1;
          return backdata;
          }
-      // select のLoopOut
+      // select ぃLoopOut
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
           "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_3);
@@ -128,10 +135,10 @@ if(errno == EINPROGRESS){
          }
       }
 
-   // 非同期通信から同期通信に
+   // 非同期通\Bから同期通\BぃH
    fcntl(sk, F_SETFL, 0);
 
-   // ソケットに関するペンディングエラーを戻す
+   // ゃXゃAットぃH閁uするペンディッEめ|ゃBッDッVを戻
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
       backdata=safe_sprintf(backdata,BUF_MAX,
        "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_13);
@@ -143,7 +150,7 @@ if(errno == EINPROGRESS){
       return backdata;
       }
    else{
-      // エラーがある場合
+      // ゃBッDッVがある堃G
       if(retval){
          backdata=safe_sprintf(backdata,BUF_MAX,
           "IP=%s Port=%d %s: TCP %s", ip_addr, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
@@ -155,7 +162,7 @@ if(errno == EINPROGRESS){
          * stat = -1;
          return backdata;
          }
-      // エラーが無い場合
+      // ゃBッDッVが無い堃G
       else{
          backdata=safe_sprintf(backdata,BUF_MAX,
           "IP=%s Port=%d TCP %s", ip_addr, port, SOCK_3);
@@ -170,8 +177,8 @@ if(errno == EINPROGRESS){
       }
    }
 
-// ネットワークにIPやホストが存在しない場合の処理
-// 非同期通信から同期通信に
+// ネットワッVゃbぃHIPやホゃPトが存在しない堃G合の凃
+// 非同期通\Bから同期通\BぃH
 fcntl(sk, F_SETFL, 0);
 
 backdata=safe_sprintf(backdata,BUF_MAX,
