@@ -31,13 +31,15 @@
 /* print conf */
   #define PRINT_CONF
 
+
 //  #define LIFE_DEBUG
 //  #define MYPEXEC_DEBUG 
 //  #define MUTEX_BUG
 //  #define MAIL_MUTEX
 //  #define MALLOC_BUG
 //  #define FREE_BUG
-//  #define THREAD_BUG
+//  #define SCAN_BUG
+//  #define CRON_BUG
 //  #define DATA_BUG
 //  #define SOCKET_BUG
 //  #define SOCKET_SENDBUG
@@ -56,6 +58,7 @@
 //  #define SCAN_PORT_DEBUG
 //  #define SNMP_DEBUG
 //  #define GETFILE_TIME_DEBUG
+// #define BAT_DEBUG
 
   typedef struct global_data global_data_t;
 
@@ -110,6 +113,11 @@
      struct file_path{ 
         char * conf_path;            /* read onlly */
         char * command_path;         /* active */
+        char * cron_path;            /* active */
+        char * cronfile_filename;    /* active */
+        char * cronlist_filename;    /* active */
+        char * cronlist_filename_2;  /* active */
+        char * cronlist_filestat;    /* active */
         char * bat_filename;         /* active */
         char * bat_filename_2;       /* active */
         char * bat_filestat;         /* active */
@@ -124,6 +132,11 @@
         char * scan_all;             /* active swap */
         }sd;
 
+     struct cron_data {
+        char * swap;                 /* active swap */
+        char * scan_all;             /* active swap */
+        }cd;
+
      };
 
 
