@@ -1,7 +1,7 @@
 #include<stdio.h>
 
 #include"zither_lint.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 
 int portcheck(int ch, char * data)
