@@ -17,8 +17,6 @@
 
 extern global_data_t gd;
 
-// char * mail_form(char *, private_data_t *, unsigned char *, int *);
-
 
 
 char * mail_form(char * swap, private_data_t * pd, unsigned char * chIpadd, int * middleno)
@@ -166,8 +164,11 @@ if(0 == self_memcmp(tool, "SET")){
 
 
 #ifdef POSTGRES_IN
-swap = safe_sprintf(swap, BUF_MAX, "%s('%d.%d.%d.%d', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s');",
-     "INSERT INTO errlog VALUES ",
+char * pgerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
+swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s', '%s');",
+     "INSERT INTO errlog ",
+     pgerrlog_table,
+     " VALUES ",
      chIpadd[0],
      chIpadd[1],
      chIpadd[2],
@@ -204,11 +205,64 @@ swap_mem(swap, (char)0x01, '\n', (int)strlen(swap));
 
 /* data insert */
 pthread_mutex_lock(&pg_mutex);
-pqexec_datain(swap);
+psqlexec_datain(swap);
 pthread_mutex_unlock(&pg_mutex);
 #endif
 
 
+#ifdef MYSQL_IN
+char * myerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
+swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s');",
+     "INSERT INTO errlog ",
+     myerrlog_table,
+     " VALUES ",
+     chIpadd[0],
+     chIpadd[1],
+     chIpadd[2],
+     chIpadd[3],
+     pd->rec.user,
+     tool,
+     utime,
+     year,
+     month,
+     day,
+     hour,
+     minute,
+     seconds,
+     stat,
+     prot,
+     com,
+     host,
+     port,
+     timeout,
+     data,
+     info,
+     plai,
+     free1,
+     free2,
+     free3,
+     free4);
+
+#ifdef MYSQL_DEBUG
+printf("MYSQL_DEBUG: mail_form(): MYSQL_INDATA > %s\n", swap);
+#endif
+
+swap_mem(swap, (char)0x01, '\n', (int)strlen(swap));
+
+
+/* data insert */
+pthread_mutex_lock(&mysql_mutex);
+mysqlexec_datain(swap);
+pthread_mutex_unlock(&mysql_mutex);
+#endif
+
+
+// メールのプライオリティー設定
+
+
+
+
+
 // メールのプライオリティー設定
 if(0 == ch_int2(plai)){
    pri = strtol(plai, (char **)NULL, 10);
