@@ -1,18 +1,7 @@
-// times.c
-// $Id: times.c,v 1.1.1.1 2007/09/19 05:49:54 sendan Exp $
-// masashi shimakura
 
-/* FreeBSD */
 #include<stdio.h>
-#include<unistd.h>
-#include<netinet/in.h>
-#include<string.h>
-#include<stdlib.h>
-#include<time.h>
 #include<arpa/inet.h>
-#include<pthread.h>
 
-#include"zither.h"
 #include<almemsys/almemsys.h>
 
 /*
@@ -20,12 +9,7 @@ int mail_time_getr(char [], int, char *);
 */
 
 
-extern struct buff_set bf;
 
-
-
-
-/* ------------ mail_time_getr --------------- */
 int mail_time_getr(char buf[], int count, char * zone)
 {
 time_t t;
