@@ -20,10 +20,16 @@ extern global_data_t gd;
 
 int malloc_set(void)
 {
-
+/* selects data base */
+if((gd.db_select=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
 /*  postgres socket */
 if((gd.pg.postgres_data=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
 if((gd.pg.pg_webserver=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+/* mysql socket */
+if((gd.mysql.mysql_server=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+if((gd.mysql.mysql_username=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+if((gd.mysql.mysql_password=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+if((gd.mysql.mysql_db=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
 
 /*  my_sock */
 if((gd.ms.ip_addr=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
