@@ -14,11 +14,11 @@
 #include"jpreturn.h"
 
 
-#ifdef POSTGRES_IN
-  #include<libpq-fe.h>
-  extern PGconn * conn;
-  extern PGresult * res;
-#endif
+// #ifdef POSTGRES_IN
+//  #include<libpq-fe.h>
+//  extern PGconn * conn;
+//  extern PGresult * res;
+// #endif
 
 
 extern global_data_t gd;
@@ -112,9 +112,12 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       #endif
 
       #ifdef POSTGRES_IN
+      char * pgerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
       char * swap = (char *)calloc(2, sizeof(char));
-      swap = safe_sprintf(swap, BUF_MAX, "%s('%d.%d.%d.%d', '%s', '%s', '%ld', '%ld', '%ld', '%ld' , '%ld', '%ld', '%ld', '%ld', '%s', '%s', '%s', '%ld', '%ld', '%s', '%s', '%ld', '%s', '%s', '%s', '%s');",
-        "INSERT INTO errlog VALUES ",
+      swap = safe_sprintf(swap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%s','%s','%s','%ld','%ld','%s','%s','%ld','%s','%s','%s','%s');",
+        "INSERT INTO errlog ",
+        pgerrlog_table,
+        " VALUES ",
         gd.ms.inip_addr[pd->rec.fdno][0],
         gd.ms.inip_addr[pd->rec.fdno][1],
         gd.ms.inip_addr[pd->rec.fdno][2],
@@ -147,11 +150,59 @@ if(((int)neg(pd->rec.user, gd.fp.neg_conf, gd.ms.inip_addr[pd->rec.fdno]))==1){
       #endif
 
       pthread_mutex_lock(&pg_mutex);
-      pqexec_datain(swap);
+      psqlexec_datain(swap);
       pthread_mutex_unlock(&pg_mutex);
       free(swap);
       #endif
 
+
+
+      #ifdef MYSQL_IN
+      char * myerrlog_table = "(cip,cname,monitor,uct,ye,mo,da,ha,mi,se,sign,proto,com,cinfo,port,wtime,pinfo,errdata,prino,free1,free2,free3,free4)"; 
+      char * myswap = (char *)calloc(2, sizeof(char));
+      myswap = safe_sprintf(myswap, BUF_MAX, "%s%s%s('%d.%d.%d.%d','%s','%s','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%ld','%s','%s','%s','%ld','%ld','%s','%s','%ld','%s','%s','%s','%s');",
+        "INSERT INTO errlog ",
+        myerrlog_table,
+        " VALUES ",
+        gd.ms.inip_addr[pd->rec.fdno][0],
+        gd.ms.inip_addr[pd->rec.fdno][1],
+        gd.ms.inip_addr[pd->rec.fdno][2],
+        gd.ms.inip_addr[pd->rec.fdno][3],
+        pd->rec.user,
+        "CONNECT",
+        (long int)time(NULL),
+        ctime_getr('y'),
+        ctime_getr('m'),
+        ctime_getr('d'),
+        ctime_getr('h'),
+        ctime_getr('i'),
+        ctime_getr('s'),
+        0,
+        "NOT",
+        "NOT",
+        "NOT",
+        0,
+        0,
+        pd->rec.info,
+        "sitar client new connection.",
+        1,
+        "NON",
+        "NON",
+        "NON",
+        "NON", ' ');
+
+      #ifdef MYSQL_DEBUG
+      printf("MYSQL_DEBUG: neg_logi(): %s\n", myswap);
+      #endif
+
+      pthread_mutex_lock(&mysql_mutex);
+      mysqlexec_datain(myswap);
+      pthread_mutex_unlock(&mysql_mutex);
+      free(myswap);
+      #endif
+
+
+
       #ifndef BIG_WOOD
       if(gd.md.in_mailonoff == 1){
          mail_grsend(pd->mail.server,
