@@ -12,7 +12,7 @@
 
 
 #include"zither.h"
-#include"almemsys.h"
+#include<almemsys/almemsys.h>
 
 extern struct global_data gd;
 
