@@ -3,12 +3,21 @@
 // masashi shimakura
 
 #ifdef POSTGRES_IN
-int pqconnect(void);
-int pqexec_datain(char *);
-int pqexec_select(char *);
-int pg_connectset(private_data_t *, char *);
+int psqlconnect(void);
+int psqlexec_datain(char *);
+int psqlexec_select(char *);
+int psql_connectset(private_data_t *, char *);
 #endif
 
+
+#ifdef MYSQL_IN
+int mysqlconnect(char *, char *, char *, char *);
+int mysql_connectset(private_data_t *, char *);
+int mysqlexec_datain(char *);
+int mysqlexec_select(char *);
+#endif
+
+
 // int socket_bind(struct sockaddr_in *, int, char *, int *);
 // int socket_accept(struct sockaddr_in *, int *, int *); 
 
