@@ -19,9 +19,16 @@ int set_data(void)
 {
 
      gd.exid.uid = 0;
+     gd.db_select = safe_memcpy(gd.db_select, "PGSQL", LOGPATH_LEN);
      gd.fp.errlog = safe_memcpy(gd.fp.errlog, "/tmp/zither_err.log", LOGPATH_LEN);
      gd.pg.postgres_data = safe_memcpy(gd.pg.postgres_data, "'127.0.0.1' port='5432' dbname='test'", LOGPATH_LEN);
      gd.pg.pg_webserver = safe_memcpy(gd.pg.pg_webserver, "localhost", LOGPATH_LEN);
+
+     gd.mysql.mysql_server = safe_memcpy(gd.mysql.mysql_server, "127.0.0.1", LOGPATH_LEN);
+     gd.mysql.mysql_username = safe_memcpy(gd.mysql.mysql_username, "masashi", LOGPATH_LEN);
+     gd.mysql.mysql_password = safe_memcpy(gd.mysql.mysql_password, "passwd", LOGPATH_LEN);
+     gd.mysql.mysql_db = safe_memcpy(gd.mysql.mysql_db, "zither", LOGPATH_LEN);
+
      gd.fp.connectlog = safe_memcpy(gd.fp.connectlog, "/tmp/zither_connect.log", LOGPATH_LEN);
      gd.fp.file_conf = safe_memcpy(gd.fp.file_conf, "/tmp/", LOGPATH_LEN);
      gd.fp.lock_path = safe_memcpy(gd.fp.lock_path, "/tmp/", LOGPATH_LEN);
