@@ -19,10 +19,18 @@
 
 #ifdef POSTGRES_IN
   #include<libpq-fe.h>
-  PGconn * conn;
+  PGconn * conn = 0;
   PGresult * res;
 #endif
 
+#ifdef MYSQL_IN
+  #include<mysql.h>
+  MYSQL mysql_buf;
+  MYSQL * my_conn = 0;
+  MYSQL_RES * my_result;
+#endif
+
+
 global_data_t gd;
 
 
@@ -62,7 +70,15 @@ gd.fp.con_fd = fd_outopen(gd.fp.connectlog, gd.fp.con_fp);
 
 #ifdef POSTGRES_IN
 pthread_mutex_init(&pg_mutex, NULL);
-gd.pg.stat = pqconnect();
+gd.pg.stat = psqlconnect();
+#endif
+
+#ifdef MYSQL_IN
+pthread_mutex_init(&mysql_mutex, NULL);
+gd.mysql.stat = mysqlconnect(gd.mysql.mysql_server, gd.mysql.mysql_username, gd.mysql.mysql_password, gd.mysql.mysql_db);
+#ifdef MYSQL_DEBUG
+printf("MYSQL_DEBUG: zither.c: MYSQL CONNECTION STATUS <%d>\n", gd.mysql.stat);
+#endif
 #endif
 
 if(-1 == (socket_bind(&gd.ms.my_addr, gd.ms.port, gd.ms.ip_addr, &gd.ms.ls))){
