@@ -64,12 +64,21 @@
 //  エラーメールに監視管理番号をURL検索させるかどうかの設定
   #define URL_SEARCH
 
-//  PostgreSQL を利用する設定
-  #define POSTGRES_IN 
+//  PostgreSQL か mysql データベースを利用する設定
+  #ifdef MYPG_IN 
+    #define POSTGRES_IN 
+    #define MYSQL_IN
+  #endif
+
 
 //  PostgreSQL のデバッグを行う場合の設定
   #ifdef POSTGRES_IN 
-  /* #define POSTGRES_DEBUG */
+  // #define POSTGRES_DEBUG 
+  #endif
+
+//  mysql データベースのデバッグを行う場合の設定
+  #ifdef MYSQL_IN 
+  //  #define MYSQL_DEBUG
   #endif
 
 
@@ -81,6 +90,10 @@
     pthread_mutex_t pg_mutex;
   #endif
 
+  #ifdef MYSQL_IN 
+    pthread_mutex_t mysql_mutex;
+  #endif
+
 
   typedef struct mail_data mail_data_t;
 
@@ -164,11 +177,20 @@
 
   struct global_data {
     pthread_t * pt;
+    char * db_select;                  // どっちのDBを使うのかの選択（まだ使ってない）
     struct {
        char * postgres_data;           /* active */
        char * pg_webserver;            /* active */
        int stat;
        }pg;
+    struct {
+       char * mysql_server;
+       char * mysql_username;
+       char * mysql_password;
+       char * mysql_db;
+       int stat;
+       }mysql;
+
     struct {
        int max_count;
        long int fdno;
